@@ -1,12 +1,12 @@
+use core::str::FromStr;
 use std::{
     fs,
     path::{Path, PathBuf},
-    str::FromStr,
 };
 
 use abscissa_core::{Command, Options, Runnable};
 
-use ibc::ics24_host::identifier::ChainId;
+use ibc::core::ics24_host::identifier::ChainId;
 use ibc_relayer::{
     config::{ChainConfig, Config},
     keyring::{HDPath, KeyEntry, KeyRing, Store},
