@@ -2,7 +2,7 @@ use alloc::collections::btree_map::BTreeMap as HashMap;
 
 use abscissa_core::{Command, Options, Runnable};
 
-use ibc::ics24_host::identifier::ChainId;
+use ibc::core::ics24_host::identifier::ChainId;
 use ibc_relayer::{
     config::{ChainConfig, Config},
     keyring::{KeyEntry, KeyRing, Store},
