@@ -1,11 +1,13 @@
-use std::{fmt, ops::Deref, str::FromStr, sync::Arc, thread};
+use alloc::sync::Arc;
+use core::{fmt, ops::Deref, str::FromStr};
+use std::thread;
 
 use abscissa_core::{application::fatal_error, Command, Options, Runnable};
 use itertools::Itertools;
 use tokio::runtime::Runtime as TokioRuntime;
 use tracing::{error, info};
 
-use ibc::{events::IbcEvent, ics24_host::identifier::ChainId};
+use ibc::{core::ics24_host::identifier::ChainId, events::IbcEvent};
 
 use ibc_relayer::{
     config::ChainConfig,
